"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DaoWorldsDeltaProcessorTaskMapper = exports.DaoWorldsDeltaMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const enums_1 = require("../../domain/enums");
const candidates_mapper_1 = require("./candidates.mapper");
const candidates2_mapper_1 = require("./candidates2.mapper");
const candperms_mapper_1 = require("./candperms.mapper");
const custodians1_mapper_1 = require("./custodians1.mapper");
const dacglobals_mapper_1 = require("./dacglobals.mapper");
const pendingpay_mapper_1 = require("./pendingpay.mapper");
const proxies_mapper_1 = require("./proxies.mapper");
const votes_mapper_1 = require("./votes.mapper");
class DaoWorldsDeltaMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    fromEntity(entity) {
        let entityData;
        switch (entity.table) {
            case enums_1.DaoWorldsTableName.Candidates:
                entityData = new candidates_mapper_1.CandidatesMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.DaoWorldsTableName.Candidates2:
                entityData = new candidates2_mapper_1.Candidates2MongoMapper().fromEntity(entity.data);
                break;
            case enums_1.DaoWorldsTableName.Candperms:
                entityData = new candperms_mapper_1.CandpermsMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.DaoWorldsTableName.Custodians1:
                entityData = new custodians1_mapper_1.Custodians1MongoMapper().fromEntity(entity.data);
                break;
            case enums_1.DaoWorldsTableName.Dacglobals:
                entityData = new dacglobals_mapper_1.DacglobalsMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.DaoWorldsTableName.Pendingpay:
                entityData = new pendingpay_mapper_1.PendingpayMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.DaoWorldsTableName.Proxies:
                entityData = new proxies_mapper_1.ProxiesMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.DaoWorldsTableName.Votes:
                entityData = new votes_mapper_1.VotesMongoMapper().fromEntity(entity.data);
                break;
        }
        const model = {
            block_timestamp: entity.blockTimestamp,
            block_num: new aw_storage_mongodb_1.MongoDB.Long(entity.blockNumber),
            code: entity.code,
            scope: entity.scope,
            table: entity.table,
            data: entityData,
            payer: entity.payer,
            primary_key: new aw_storage_mongodb_1.MongoDB.Long(entity.primaryKey),
            present: entity.present,
        };
        if (entity.id && aw_storage_mongodb_1.MongoDB.ObjectId.isValid(entity.id)) {
            model._id = new aw_storage_mongodb_1.MongoDB.ObjectId(entity.id);
        }
        return model;
    }
    toEntity(mongoModel) {
        let data;
        switch (mongoModel.table) {
            case enums_1.DaoWorldsTableName.Candidates:
                data = new candidates_mapper_1.CandidatesMongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.DaoWorldsTableName.Candidates2:
                data = new candidates2_mapper_1.Candidates2MongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.DaoWorldsTableName.Candperms:
                data = new candperms_mapper_1.CandpermsMongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.DaoWorldsTableName.Custodians1:
                data = new custodians1_mapper_1.Custodians1MongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.DaoWorldsTableName.Dacglobals:
                data = new dacglobals_mapper_1.DacglobalsMongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.DaoWorldsTableName.Pendingpay:
                data = new pendingpay_mapper_1.PendingpayMongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.DaoWorldsTableName.Proxies:
                data = new proxies_mapper_1.ProxiesMongoMapper().toEntity(mongoModel.data);
                break;
            case enums_1.DaoWorldsTableName.Votes:
                data = new votes_mapper_1.VotesMongoMapper().toEntity(mongoModel.data);
                break;
        }
        const { _id, block_num, code, scope, table, payer, primary_key, present, block_timestamp, } = mongoModel;
        return new aw_core_1.ContractDelta(_id.toString(), (0, aw_core_1.parseToBigInt)(block_num), code, scope, table, data, payer, (0, aw_core_1.parseToBigInt)(primary_key), present, block_timestamp);
    }
}
exports.DaoWorldsDeltaMongoMapper = DaoWorldsDeltaMongoMapper;
class DaoWorldsDeltaProcessorTaskMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('method not implemented');
    }
    toEntity(rawModel) {
        let data;
        switch (rawModel.table) {
            case enums_1.DaoWorldsTableName.Candidates:
                data = new candidates_mapper_1.CandidatesRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.DaoWorldsTableName.Candidates2:
                data = new candidates2_mapper_1.Candidates2RawMapper().toEntity(rawModel.data);
                break;
            case enums_1.DaoWorldsTableName.Candperms:
                data = new candperms_mapper_1.CandpermsRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.DaoWorldsTableName.Custodians1:
                data = new custodians1_mapper_1.Custodians1RawMapper().toEntity(rawModel.data);
                break;
            case enums_1.DaoWorldsTableName.Dacglobals:
                data = new dacglobals_mapper_1.DacglobalsRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.DaoWorldsTableName.Pendingpay:
                data = new pendingpay_mapper_1.PendingpayRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.DaoWorldsTableName.Proxies:
                data = new proxies_mapper_1.ProxiesRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.DaoWorldsTableName.Votes:
                data = new votes_mapper_1.VotesRawMapper().toEntity(rawModel.data);
                break;
        }
        const { block_num, code, scope, table, payer, primary_key, present, block_timestamp, } = rawModel;
        return new aw_core_1.ContractDelta('', (0, aw_core_1.parseToBigInt)(block_num), code, scope, table, data, payer, (0, aw_core_1.parseToBigInt)(primary_key), present, block_timestamp);
    }
}
exports.DaoWorldsDeltaProcessorTaskMapper = DaoWorldsDeltaProcessorTaskMapper;
